import { 
  select, 
  csv, 
  scaleLinear, 
  scaleTime,
  extent, 
  axisLeft,
  axisBottom,
  area,
  curveBasis
} from 'd3';

const svg = select('svg');

const height = +svg.attr('height');
const width = +svg.attr('width');

const render = data => {
 
  const title = 'A week in San Francisco';
  
  const xValue = d => d.timestamp;
  const xAxisLabel = 'Time';
  
  const yValue = d => d.temperature;
  const yAxisLabel = 'Temperature';
  
  const circleRadius = 6;
  const margin = {top: 60, right: 40, bottom: 90, left: 105};
  const innerWidth = width - margin.left - margin.right;
  const innerHeight = height - margin.top - margin.bottom;
  
  const xScale = scaleTime()
  	.domain(extent(data, xValue))
  	.range([0, innerWidth]);
  
  const yScale = scaleLinear()
  	.domain(extent(data, yValue))
  	.range([innerHeight, 0])
  	.nice();
  
  const g = svg.append('g')
  	.attr('transform', `translate(${margin.left}, ${margin.top})`);
  
  const xAxis = axisBottom(xScale)
  	.ticks(6)
  	.tickSize(-innerHeight)
  	.tickPadding(15);
  
  const yAxis = axisLeft(yScale)
  	.tickSize(-innerWidth)
  	.tickPadding(10);
  
  const yAxisG = g.append('g').call(yAxis);
  
  yAxisG.select('.domain').remove();
  
  const xAxisG = g.append('g').call(xAxis)
  	.attr('transform', `translate(0, ${innerHeight})`);
  
  xAxisG.select('.domain').remove();
  
  xAxisG.append('text')
  	.attr('y', 75)
  	.attr('x', innerWidth/2)
  	.attr('fill', 'black')
  	.attr('class', 'axis-label')
  	.text(xAxisLabel);
  
  const areaGenerator = area()
  	.y0(innerHeight)
  	.x(d => xScale(xValue(d)))
  	.y1(d => yScale(yValue(d)))
  	.curve(curveBasis);
  
  g.append('path')
  	.attr('class', 'line-path')
  	.attr('d', areaGenerator(data));
  
  g.append('text')
  	.attr('y', -10)
  	.attr('class', 'title')
  	.text(title);
  
  yAxisG.append('text')
  	.attr('y', -60)
  	.attr('x', - innerHeight / 2)
  	.attr('fill', 'black')
  	.attr('class', 'axis-label')
  	.attr('transform', 'rotate(-90)')
  	.attr('text-anchor', 'middle')
  	.text(yAxisLabel);
  
};

csv('https://gist.githubusercontent.com/curran/60b40877ef898f19aeb8/raw/9476be5bd15fb15a6d5c733dd79788fb679c9be9/week_temperature_sf.csv')
  .then(data => {
  console.log(data)
    data.forEach(d => {
      /*temperature: "23.9516625615764"
			timestamp: "2015-03-20T21:00:00.000Z"*/
      d.temperature = +d.temperature;
      d.timestamp = new Date(d.timestamp);
    });
    render(data);
});










